YARP 2.2.5 (2009-12-04)                                                {#v2_2_5}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.4...v2.2.5`):

```
   126	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    28	Lorenzo Natale <lorenzo.natale@iit.it>
     8	Ugo Pattacini <ugo.pattacini@iit.it>
     4	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     1	Alessandro Scalzo <alessandro.scalzo@iit.it>
     1	YARP Developers <yarp0-devel@lists.sourceforge.net>
```
